@@ -1,18 +1,32 @@
-# Close a connection to an OpenOffice.org database (odb) file
-# Author : Sylvain Mareschal
+### Copyright (C) 2012 Sylvain Mareschal <maressyl@gmail.com>
+### 
+### This program is free software: you can redistribute it and/or modify
+### it under the terms of the GNU General Public License as published by
+### the Free Software Foundation, either version 3 of the License, or
+### (at your option) any later version.
+### 
+### This program is distributed in the hope that it will be useful,
+### but WITHOUT ANY WARRANTY; without even the implied warranty of
+### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+### GNU General Public License for more details.
+### 
+### You should have received a copy of the GNU General Public License
+### along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+# Close a connection to an Open Document Database file
 odb.close = function(
 		odb,
 		write = TRUE
 		)
 	{
 	# Class checks
-	if (!is(odb, "odb")) {
-		stop("'odb' must be an 'odb' object")
+	if(!is(odb, "ODB")) {
+		stop("'odb' must be an 'ODB' object")
 	}
 	validObject(odb)
 	
 	# Updates the .odb file properly
-	if (write) {
+	if(isTRUE(write)) {
 		# HSQLDB disconnection with file compaction
 		tryCatch(
 			dbSendUpdate(odb, "SHUTDOWN COMPACT"),
@@ -32,13 +46,14 @@ odb.close = function(
 		}
 		
 		# Updates the ODB archive
-		odb.zip(
-			archive = odb@odbFile,
+		wd <- getwd()
+		setwd(odb@directory)
+		utils::zip(
+			zipfile = odb@odbFile,
 			files = c("content.xml", "database"),
-			from = odb@directory,
-			recursive = TRUE,
-			quiet = TRUE
+			flags = "-r9Xq"
 		)
+		setwd(wd)
 	} else {
 		# HSQLDB disconnection attempt
 		tryCatch(
